==> roccat-tools-1.0.0.tar.bz2: roccat-tools-1.0.0/pyra/libpyra/pyra_settings.c <==
/*
 * This file is part of roccat-tools.
 *
 * roccat-tools is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * roccat-tools is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with roccat-tools. If not, see <http://www.gnu.org/licenses/>.
 */

#include "roccat/pyra.h"

/*
 * TODO if actual == startup profile:
 * - remove startup profile functions
 * - implement pyra_profile_activate with code like set_startup_profile_cb()
 *   or writable integer sysfs attr
 */

static gchar const * const settings_name = "settings";

PyraSettings *pyra_settings_read(RoccatDevice *pyra, GError **error) {
	return (PyraSettings *)roccat_device_read(pyra, settings_name, sizeof(PyraSettings), error);
}

static void pyra_settings_finalize(PyraSettings *settings) {
	settings->command = PYRA_COMMAND_SETTINGS;
	settings->size = sizeof(PyraSettings);
}

gboolean pyra_settings_write(RoccatDevice *pyra, PyraSettings *settings, GError **error) {
	pyra_settings_finalize(settings);
	return roccat_device_write(pyra, settings_name, (gchar const *)settings, sizeof(PyraSettings), error);
}

guint pyra_actual_profile_read(RoccatDevice *pyra, GError **error) {
	guint result;
	PyraSettings *settings;

	settings = pyra_settings_read(pyra, error);
	if (*error)
		return 0;

	result = settings->startup_profile;
	g_free(settings);
	return result;
}

gboolean pyra_actual_profile_write(RoccatDevice *pyra, guint profile_index, GError **error) {
	PyraSettings settings;

	g_assert(profile_index < PYRA_PROFILE_NUM);

	settings.startup_profile = profile_index;

	return pyra_settings_write(pyra, &settings, error);
}

==> roccat-tools-1.6.0.tar.bz2: roccat-tools-1.6.0/pyra/libpyra/pyra_settings.c <==
/*
 * This file is part of roccat-tools.
 *
 * roccat-tools is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * roccat-tools is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with roccat-tools. If not, see <http://www.gnu.org/licenses/>.
 */

#include "pyra.h"
#include "roccat_device_sysfs.h"

/*
 * TODO if actual == startup profile:
 * - remove startup profile functions
 * - implement pyra_profile_activate with code like set_startup_profile_cb()
 *   or writable integer sysfs attr
 */

static gchar const * const settings_name = "settings";

PyraSettings *pyra_settings_read(RoccatDevice *pyra, GError **error) {
	return (PyraSettings *)roccat_device_sysfs_read(pyra, settings_name, sizeof(PyraSettings), error);
}

static void pyra_settings_finalize(PyraSettings *settings) {
	settings->command = PYRA_COMMAND_SETTINGS;
	settings->size = sizeof(PyraSettings);
}

gboolean pyra_settings_write(RoccatDevice *pyra, PyraSettings *settings, GError **error) {
	pyra_settings_finalize(settings);
	return roccat_device_sysfs_write(pyra, settings_name, (gchar const *)settings, sizeof(PyraSettings), error);
}

guint pyra_actual_profile_read(RoccatDevice *pyra, GError **error) {
	guint result;
	PyraSettings *settings;

	settings = pyra_settings_read(pyra, error);
	if (*error)
		return 0;

	result = settings->startup_profile;
	g_free(settings);
	return result;
}

gboolean pyra_actual_profile_write(RoccatDevice *pyra, guint profile_index, GError **error) {
	PyraSettings settings;

	g_assert(profile_index < PYRA_PROFILE_NUM);

	settings.startup_profile = profile_index;

	return pyra_settings_write(pyra, &settings, error);
}
